/**
 *******************************************************************************
 * @file    TMPM440_cg.h
 * @brief   This file provides all the functions prototypes for CG driver.
 * @version V2.0.2.4
 * @date    2014/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __TMPM440_CG_H
#define __TMPM440_CG_H


#ifdef __cplusplus
extern "C" {
#endif                          /* __cplusplus */

/* Includes ------------------------------------------------------------------*/
#include "TMPM440.h"
#include "tx04_common.h"

#ifdef __IAR_SYSTEMS_ICC__
#if 1 != __LITTLE_ENDIAN__
#pragma bitfields=disjoint_types
#endif
#endif


#if defined(__TMPM440_CG_H)
/** @addtogroup TX04_Periph_Driver
  * @{
  */

/** @addtogroup CG
  * @{
  */

/** @addtogroup CG_Exported_types
  * @{
  */

    typedef enum {
        CG_DIVIDE_1 = 0U,
        CG_DIVIDE_2 = 1U,
        CG_DIVIDE_4 = 2U,
        CG_DIVIDE_8 = 3U,
        CG_DIVIDE_16 = 4U,
        CG_DIVIDE_32 = 5U,
        CG_DIVIDE_64 = 6U,
        CG_DIVIDE_128 = 7U,
        CG_DIVIDE_256 = 8U,
        CG_DIVIDE_512 = 9U,
        CG_DIVIDE_UNKNOWN = 10U,
        CG_DIVIDE_MAX = 11U
    } CG_DivideLevel;
#define IS_CG_GEAR_DIVIDE_LEVEL(param)   ((param) <= CG_DIVIDE_16)

#define IS_CG_DIVIDE_FC_LEVEL(param)        ((param) <= CG_DIVIDE_32)
#define IS_CG_DIVIDE_FGEAR_LEVEL(param)     ((param) <= CG_DIVIDE_512)


    typedef enum {
        CG_FOSC_OSC_EXT = 0U,
        CG_FOSC_OSC_INT = 1U,
        CG_FOSC_CLKIN_EXT = 2U,
    } CG_FoscSrc;
#define IS_CG_FOSC_SRC(param)           (((param) == CG_FOSC_OSC_EXT) || \
                                         ((param) == CG_FOSC_OSC_INT) || \
                                         ((param) == CG_FOSC_CLKIN_EXT))
#define IS_CG_FOSC_STATE(param)         (((param) == CG_FOSC_OSC_EXT) || \
                                         ((param) == CG_FOSC_OSC_INT) )

    typedef enum {
        CG_SCOUT_FC_DIVIDE_4 = 0U,
        CG_SCOUT_FC_DIVIDE_8 = 1U,
        CG_SCOUT_FOSC = 2U,
        CG_SCOUT_LOW = 3U       /* SCOUT output is prohibited, fix to '0' */
    } CG_SCOUTSrc;
#define IS_CG_SCOUT_SRC(param)        ((param) <= CG_SCOUT_LOW)

    typedef enum {
        CG_WARM_UP_SRC_OSC_EXT = 0U,
        CG_WARM_UP_SRC_OSC_INT = 1U,
    } CG_WarmUpSrc;
#define IS_CG_WARM_UP_SRC(param)      (((param) == CG_WARM_UP_SRC_OSC_EXT) || \
                                       ((param) == CG_WARM_UP_SRC_OSC_INT))

    typedef enum {
        CG_FC_SRC_FOSC = 0U,
        CG_FC_SRC_FPLL = 1U
    } CG_FcSrc;
#define IS_CG_FC_SRC(param)         ((param) <= CG_FC_SRC_FPLL)

    typedef enum {
        CG_TMRD_UNIT_A = 0U,
    } CG_TmrdUnit;
#define IS_CG_TMRD_UNIT(param)      (((param) == CG_TMRD_UNIT_A))

    typedef enum {
        CG_FTMRD_SRC_FC = 0U,   /* use fc as clock source for TMRD */
        CG_FTMRD_SRC_HALF_FC = 1U,      /* use fc/2 as clock source for TMRD */
        CG_FTMRD_SRC_QUARTER_FC = 2U,   /* use fc/4 as clock source for TMRD */
        CG_FTMRD_SRC_UNKNOWN = 3U
    } CG_FtmrdSrc;
#define IS_CG_FTMRD_SRC(param)      (((param) <= CG_FTMRD_SRC_QUARTER_FC))

    typedef enum {
        CG_FADC_SRC_FC = 0U,    /* use fc as clock source for ADC */
        CG_FADC_SRC_FPLL = 1U,  /* use FPLL1 as clock source for ADC */
    } CG_FadcSrc;
#define IS_CG_FADC_SRC(param)      (((param) <= CG_FADC_SRC_FPLL))


/* PLL0 for fsys */
#define CG_FPLL0_IN8_OUT40  ((uint32_t)(0x7026U << 1U)) /* 5 fold,  input 8MHz, output 40MHz */
#define CG_FPLL0_IN8_OUT48  ((uint32_t)(0x782EU << 1U)) /* 6 fold,  input 8MHz, output 48MHz */
#define CG_FPLL0_IN8_OUT64  ((uint32_t)(0x78BEU << 1U)) /* 8 fold,  input 8MHz, output 64MHz */
#define CG_FPLL0_IN8_OUT80  ((uint32_t)(0x704DU << 1U)) /* 10 fold, input 8MHz, output 80MHz */
#define CG_FPLL0_IN10_OUT50 ((uint32_t)(0x7026U << 1U)) /* 5 fold,  input 10MHz, output 50MHz */
#define CG_FPLL0_IN10_OUT60 ((uint32_t)(0x782EU << 1U)) /* 6 fold,  input 10MHz, output 60MHz */
#define CG_FPLL0_IN10_OUT80     ((uint32_t)(0x78BEU << 1U))     /* 8 fold,  input 10MHz, output 80MHz */
#define CG_FPLL0_IN10_OUT100    ((uint32_t)(0x704DU << 1U))     /* 10 fold, input 10MHz, output 100MHz */

#define IS_CG_FPLL_VALUE(param)      (((param) == CG_FPLL0_IN8_OUT40) || \
                                      ((param) == CG_FPLL0_IN8_OUT48) || \
                                      ((param) == CG_FPLL0_IN8_OUT64) || \
                                      ((param) == CG_FPLL0_IN8_OUT80) || \
                                      ((param) == CG_FPLL0_IN10_OUT80))

/* PLL1 for ADC clock */
#define CG_FPLL1_IN8_OUT64  ((uint32_t)(((0x0CU << 28U) | (0x1EU << 17U))))     /* 8 fold,  input 8MHz, output 64MHz */
#define CG_FPLL1_IN8_OUT80  ((uint32_t)(((0x0EU << 28U) | (0x26U << 17U))))     /* 10 fold, input 8MHz, output 80MHz */
#define CG_FPLL1_IN10_OUT80     CG_FPLL1_IN8_OUT64      /* 8 fold,  input 10MHz, output 80MHz */
#define CG_FPLL1_IN10_OUT100    CG_FPLL1_IN8_OUT80      /* 10 fold, input 10MHz, output 100MHz */
#define IS_CG_FPLL1_VALUE(param)      (((param) == CG_FPLL1_IN8_OUT64) || \
                                      ((param) == CG_FPLL1_IN8_OUT80))

    typedef enum {
        CG_STBY_MODE_UNKNOWN = 0U,
        CG_STBY_MODE_STOP1 = 1U,
        CG_STBY_MODE_IDLE = 3U,
        CG_STBY_MODE_STOP2 = 5U,
        CG_STBY_MODE_MAX = 8U
    } CG_STBYMode;
#define IS_CG_STBY_MODE(param)      (((param) == CG_STBY_MODE_STOP1) || \
                                     ((param) == CG_STBY_MODE_IDLE)|| \
                                     ((param) == CG_STBY_MODE_STOP2))

    typedef enum {
        CG_PHIT0_SRC_FGEAR = 0U,
        CG_PHIT0_SRC_FC = 1U,
        CG_PHIT0_SRC_MAX = 2U
    } CG_PhiT0Src;
#define IS_CG_PHIT0_SRC(param)      (((param) == CG_PHIT0_SRC_FGEAR) || \
                                     ((param) == CG_PHIT0_SRC_FC))

    typedef enum {
        CG_INT_SRC_0 = 0U,
        CG_INT_SRC_1 = 1U,
        CG_INT_SRC_2 = 2U,
        CG_INT_SRC_3 = 3U,
        CG_INT_SRC_4 = 4U,
        CG_INT_SRC_5 = 5U,
        CG_INT_SRC_6 = 6U,
        CG_INT_SRC_7 = 7U,
        CG_INT_SRC_8 = 8U,
        CG_INT_SRC_9 = 9U,
        CG_INT_SRC_A = 10U,
        CG_INT_SRC_B = 11U,
        CG_INT_SRC_C = 12U,
        CG_INT_SRC_D = 13U,
        CG_INT_SRC_E = 14U,
        CG_INT_SRC_F = 15U,
        CG_INT_SRC_10 = 16U,
        CG_INT_SRC_11 = 17U,
        CG_INT_SRC_12 = 18U,
        CG_INT_SRC_13 = 19U,
        CG_INT_SRC_14 = 20U,
        CG_INT_SRC_15 = 21U,
        CG_INT_SRC_INTKWUP0 = 22U,
        CG_INT_SRC_INTKWUP1 = 23U,
        CG_INT_SRC_INTKSCAN = 24U,
        CG_INT_SRC_INTRTC = 25U,
        CG_INT_SRC_INTPHC00 = 26U,
        CG_INT_SRC_INTPHC01 = 27U,
        CG_INT_SRC_INTPHC0EVRY = 28U,
        CG_INT_SRC_INTPHC10 = 29U,
        CG_INT_SRC_INTPHC11 = 30U,
        CG_INT_SRC_INTPHC1EVRY = 31U,
    } CG_INTSrc;
#define IS_CG_INT_SRC(param)        ((param) <= CG_INT_SRC_INTPHC1EVRY)


    typedef enum {
        CG_INT_ACTIVE_STATE_L = 0x00U,
        CG_INT_ACTIVE_STATE_H = 0x10U,
        CG_INT_ACTIVE_STATE_FALLING = 0x20U,
        CG_INT_ACTIVE_STATE_RISING = 0x30U,
        CG_INT_ACTIVE_STATE_BOTH_EDGES = 0x40U,
        CG_INT_ACTIVE_STATE_INVALID = 0x50U
    } CG_INTActiveState;
#define IS_CG_INT_ACTIVE_STATE_A(param)  (((param) == CG_INT_ACTIVE_STATE_L) || \
                                          ((param) == CG_INT_ACTIVE_STATE_H) || \
                                          ((param) == CG_INT_ACTIVE_STATE_FALLING) || \
                                          ((param) == CG_INT_ACTIVE_STATE_RISING) || \
                                          ((param) == CG_INT_ACTIVE_STATE_BOTH_EDGES))

#define IS_CG_INT_ACTIVE_STATE_B(param)   ((param) == CG_INT_ACTIVE_STATE_H)
#define IS_CG_INT_ACTIVE_STATE_C(param)   ((param) == CG_INT_ACTIVE_STATE_FALLING)
#define IS_CG_INT_ACTIVE_STATE_D(param)   ((param) == CG_INT_ACTIVE_STATE_RISING)

#if defined ( __CC_ARM )        /* Keil */
#ifdef __BIG_ENDIAN
    typedef union {
        uint32_t All;
        struct {
            uint32_t Reserved2:25;
            uint32_t PowerOnReset2:1;   /* reset by power on */
            uint32_t Reserved1:1;
            uint32_t SYSReset:1;        /* reset by SYSResetREQ */
            uint32_t STOP2Reset:1;      /* reset by releasing STOP2 */
            uint32_t WDTReset:1;        /* reset by watch dog */
            uint32_t PinReset:1;        /* reset by reset pin */
            uint32_t PowerOnReset1:1;   /* reset by power on */
        } Bit;
    } CG_ResetFlag;
#else
    typedef union {
        uint32_t All;
        struct {
            uint32_t PowerOnReset1:1;   /* reset by power on */
            uint32_t PinReset:1;        /* reset by reset pin */
            uint32_t WDTReset:1;        /* reset by watch dog */
            uint32_t STOP2Reset:1;      /* reset by releasing STOP2 */
            uint32_t SYSReset:1;        /* reset by SYSResetREQ */
            uint32_t Reserved1:1;
            uint32_t PowerOnReset2:1;   /* reset by power on */
            uint32_t Reserved2:25;
        } Bit;
    } CG_ResetFlag;
#endif
#elif  defined(__IAR_SYSTEMS_ICC__)     /* IAR */
    typedef union {
        uint32_t All;
        struct {
            uint32_t PowerOnReset1:1;   /* reset by power on */
            uint32_t PinReset:1;        /* reset by reset pin */
            uint32_t WDTReset:1;        /* reset by watch dog */
            uint32_t STOP2Reset:1;      /* reset by releasing STOP2 */
            uint32_t SYSReset:1;        /* reset by SYSResetREQ */
            uint32_t Reserved1:1;
            uint32_t PowerOnReset2:1;   /* reset by power on */
            uint32_t Reserved2:25;
        } Bit;
    } CG_ResetFlag;
#endif

#define CG_PSC_CLK_SUPPLY                   ((uint32_t)0x00200000)
#define CG_ADC_C_CLK_SUPPLY                 ((uint32_t)0x00100000)
#define CG_ADC_B_CLK_SUPPLY                 ((uint32_t)0x00080000)
#define CG_ADC_A_CLK_SUPPLY                 ((uint32_t)0x00040000)
#define CG_PSCADCALL_CLK_SUPPLY             ((uint32_t)0x003C0000)
#define IS_CG_PERIPH_CLK_SUPPLY(param)      (((param) & CG_PSCADCALL_CLK_SUPPLY) && \
                                             (!((param) & (uint32_t) (~CG_PSCADCALL_CLK_SUPPLY))))

#define FCLK_A_TMRB10   ((uint32_t)(0x01U << 0U))
#define FCLK_A_TMRB11   ((uint32_t)(0x01U << 1U))
#define FCLK_A_TMRB12   ((uint32_t)(0x01U << 2U))
#define FCLK_A_TMRB13   ((uint32_t)(0x01U << 3U))
#define FCLK_A_TMRB14   ((uint32_t)(0x01U << 4U))
#define FCLK_A_TMRB15   ((uint32_t)(0x01U << 5U))
#define FCLK_A_TMRB16   ((uint32_t)(0x01U << 6U))
#define FCLK_A_TMRB17   ((uint32_t)(0x01U << 7U))
#define FCLK_A_TMRB18   ((uint32_t)(0x01U << 8U))
#define FCLK_A_TMRB19   ((uint32_t)(0x01U << 9U))
#define FCLK_A_DAC0     ((uint32_t)(0x01U << 10U))
#define FCLK_A_DAC1     ((uint32_t)(0x01U << 11U))
#define FCLK_A_EBIF     ((uint32_t)(0x01U << 12U))
#define FCLK_A_UART0    ((uint32_t)(0x01U << 13U))
#define FCLK_A_UART1    ((uint32_t)(0x01U << 14U))
#define FCLK_A_DMACA    ((uint32_t)(0x01U << 15U))
#define FCLK_A_DMACB    ((uint32_t)(0x01U << 16U))
#define FCLK_A_DMACC    ((uint32_t)(0x01U << 17U))
#define FCLK_A_NU18     ((uint32_t)(0x01U << 18U))
#define FCLK_A_PORTA    ((uint32_t)(0x01U << 19U))
#define FCLK_A_PORTB    ((uint32_t)(0x01U << 20U))
#define FCLK_A_PORTC    ((uint32_t)(0x01U << 21U))
#define FCLK_A_PORTD    ((uint32_t)(0x01U << 22U))
#define FCLK_A_PORTE    ((uint32_t)(0x01U << 23U))
#define FCLK_A_PORTF    ((uint32_t)(0x01U << 24U))
#define FCLK_A_PORTG    ((uint32_t)(0x01U << 25U))
#define FCLK_A_PORTH    ((uint32_t)(0x01U << 26U))
#define FCLK_A_PORTJ    ((uint32_t)(0x01U << 27U))
#define FCLK_A_PORTK    ((uint32_t)(0x01U << 28U))
#define FCLK_A_PORTL    ((uint32_t)(0x01U << 29U))
#define FCLK_A_PORTM    ((uint32_t)(0x01U << 30U))
#define FCLK_A_PORTN    ((uint32_t)(0x01U << 31U))
#define FCLK_A_ALL      ((uint32_t)(0xFFFBFFFFU))
#define IS_CG_FCLK_SUPPLYA(param)        ( (((param) != FCLK_A_NU18)) && ((param) > 0U ))

#define FCLK_B_PORTP    ((uint32_t)(0x01U << 0U))
#define FCLK_B_PORTR    ((uint32_t)(0x01U << 1U))
#define FCLK_B_PORTT    ((uint32_t)(0x01U << 2U))
#define FCLK_B_PORTU    ((uint32_t)(0x01U << 3U))
#define FCLK_B_PORTV    ((uint32_t)(0x01U << 4U))
#define FCLK_B_PORTW    ((uint32_t)(0x01U << 5U))
#define FCLK_B_PORTY    ((uint32_t)(0x01U << 6U))
#define FCLK_B_PORTAA   ((uint32_t)(0x01U << 7U))
#define FCLK_B_PORTAB   ((uint32_t)(0x01U << 8U))
#define FCLK_B_PORTAC   ((uint32_t)(0x01U << 9U))
#define FCLK_B_PORTAD   ((uint32_t)(0x01U << 10U))
#define FCLK_B_PORTAE   ((uint32_t)(0x01U << 11U))
#define FCLK_B_PORTAF   ((uint32_t)(0x01U << 12U))
#define FCLK_B_PORTAG   ((uint32_t)(0x01U << 13U))
#define FCLK_B_PORTAH   ((uint32_t)(0x01U << 14U))
#define FCLK_B_PORTAJ   ((uint32_t)(0x01U << 15U))
#define FCLK_B_NU16     ((uint32_t)(0x01U << 16U))
#define FCLK_B_ADCA     ((uint32_t)(0x01U << 17U))
#define FCLK_B_ADCB     ((uint32_t)(0x01U << 18U))
#define FCLK_B_ADCC     ((uint32_t)(0x01U << 19U))
#define FCLK_B_EPHC     ((uint32_t)(0x01U << 20U))
#define FCLK_B_SBI      ((uint32_t)(0x01U << 21U))
#define FCLK_B_WDT      ((uint32_t)(0x01U << 22U))
#define FCLK_B_ALL      ((uint32_t)(0x007EFFFFU))
#define IS_CG_FCLK_SUPPLYB(param)        (((param) != FCLK_B_NU16) && ((param) <= FCLK_B_ALL) && ((param) > 0U))

#define FC_A_ESIO0      ((uint32_t)(0x01U << 0U))
#define FC_A_ESIO1      ((uint32_t)(0x01U << 1U))
#define FC_A_ESIO2      ((uint32_t)(0x01U << 2U))
#define FC_A_TMRD       ((uint32_t)(0x01U << 3U))
#define FC_A_SIO_UART0  ((uint32_t)(0x01U << 4U))
#define FC_A_SIO_UART1  ((uint32_t)(0x01U << 5U))
#define FC_A_SIO_UART2  ((uint32_t)(0x01U << 6U))
#define FC_A_SIO_UART3  ((uint32_t)(0x01U << 7U))
#define FC_A_SIO_UART4  ((uint32_t)(0x01U << 8U))
#define FC_A_SIO_UART5  ((uint32_t)(0x01U << 9U))
#define FC_A_TMRB00     ((uint32_t)(0x01U << 10U))
#define FC_A_TMRB01     ((uint32_t)(0x01U << 11U))
#define FC_A_TMRB02     ((uint32_t)(0x01U << 12U))
#define FC_A_TMRB03     ((uint32_t)(0x01U << 13U))
#define FC_A_TMRB04     ((uint32_t)(0x01U << 14U))
#define FC_A_TMRB05     ((uint32_t)(0x01U << 15U))
#define FC_A_TMRB06     ((uint32_t)(0x01U << 16U))
#define FC_A_TMRB07     ((uint32_t)(0x01U << 17U))
#define FC_A_TMRB08     ((uint32_t)(0x01U << 18U))
#define FC_A_TMRB09     ((uint32_t)(0x01U << 19U))
#define FC_A_TMRCCAP0   ((uint32_t)(0x01U << 20U))
#define FC_A_TMRCCAP1   ((uint32_t)(0x01U << 21U))
#define FC_A_TMRCCAP2   ((uint32_t)(0x01U << 22U))
#define FC_A_TMRCCAP3   ((uint32_t)(0x01U << 23U))
#define FC_A_TMRCCMP0   ((uint32_t)(0x01U << 24U))
#define FC_A_TMRCCMP1   ((uint32_t)(0x01U << 25U))
#define FC_A_TMRCCMP2   ((uint32_t)(0x01U << 26U))
#define FC_A_TMRCCMP3   ((uint32_t)(0x01U << 27U))
#define FC_A_TMRCCMP4   ((uint32_t)(0x01U << 28U))
#define FC_A_TMRCCMP5   ((uint32_t)(0x01U << 29U))
#define FC_A_TMRCCMP6   ((uint32_t)(0x01U << 30U))
#define FC_A_TMRCCMP7   ((uint32_t)(0x01U << 31U))
#define FC_A_ALL        ((uint32_t)(0xFFFFFFFFU))
/* #define IS_CG_FC_SUPPLYA(param)        ( ((param) <= FC_A_ALL) && (param) > 0U ) */


#define FC_B_TMRCTBT    ((uint32_t)(0x01U << 0U))
#define FC_B_ALL        ((uint32_t)(0x01U))
#define IS_CG_FC_SUPPLYB(param)        ((param) == FC_B_ALL)

/** @} */
/* End of group CG_Exported_types */

/** @defgroup CG_Exported_FunctionPrototypes
  * @{
  */
    void CG_SetFgearLevel(CG_DivideLevel DivideFgearFromFc);
    CG_DivideLevel CG_GetFgearLevel(void);
    void CG_SetPhiT0Src(CG_PhiT0Src PhiT0Src);
    CG_PhiT0Src CG_GetPhiT0Src(void);
    Result CG_SetPhiT0Level(CG_DivideLevel DividePhiT0FromFc);
    CG_DivideLevel CG_GetPhiT0Level(void);
    void CG_SetSCOUTSrc(CG_SCOUTSrc Source);
    CG_SCOUTSrc CG_GetSCOUTSrc(void);
    void CG_SetWarmUpTime(CG_WarmUpSrc Source, uint16_t Time);
    void CG_StartWarmUp(void);
    WorkState CG_GetWarmUpState(void);
    Result CG_SetFPLLValue(uint32_t NewValue);
    Result CG_SetPLL(FunctionalState NewState);
    FunctionalState CG_GetPLLState(void);
    Result CG_SetFPLLForADCValue(uint32_t NewValue);
    void CG_SetFadcSrc(CG_FadcSrc FadcSrc);
    void CG_SetPLL1ForADC(FunctionalState NewState);
    Result CG_SetFosc(CG_FoscSrc Source, FunctionalState NewState);
    void CG_SetFoscSrc(CG_FoscSrc Source);
    CG_FoscSrc CG_GetFoscSrc(void);
    FunctionalState CG_GetFoscState(CG_FoscSrc Source);
    Result CG_SetFs(FunctionalState NewState);
    FunctionalState CG_GetFsState(void);
    void CG_SetSTBYMode(CG_STBYMode Mode);
    CG_STBYMode CG_GetSTBYMode(void);
    void CG_SetPinStateInStop1Mode(FunctionalState NewState);
    FunctionalState CG_GetPinStateInStop1Mode(void);
    void CG_SetPortKeepInStop2Mode(FunctionalState NewState);
    FunctionalState CG_GetPortKeepInStop2Mode(void);
    Result CG_SetFcSrc(CG_FcSrc Source);
    CG_FcSrc CG_GetFcSrc(void);
    void CG_SetFtmrdSrc(CG_TmrdUnit TmrdUnit, CG_FtmrdSrc FtmrdSrc);
    CG_FtmrdSrc CG_GetFtmrdSrc(CG_TmrdUnit TmrdUnit);
    void CG_SetTMRDClk(CG_TmrdUnit TmrdUnit, FunctionalState NewState);
    FunctionalState CG_GetTMRDClkState(CG_TmrdUnit TmrdUnit);
    void CG_SetProtectCtrl(FunctionalState NewState);
    void CG_SetSTBYReleaseINTSrc(CG_INTSrc INTSource,
                                 CG_INTActiveState ActiveState, FunctionalState NewState);
    CG_INTActiveState CG_GetSTBYReleaseINTState(CG_INTSrc INTSource);
    void CG_ClearINTReq(CG_INTSrc INTSource);
    CG_ResetFlag CG_GetResetFlag(void);
    void CG_SetPeriphClkSupply(uint32_t Periph, FunctionalState NewState);
    void CG_SetFclkPeriphA(uint32_t Periph, FunctionalState NewState);
    void CG_SetFclkPeriphB(uint32_t Periph, FunctionalState NewState);
    void CG_SetFcPeriphA(uint32_t Periph, FunctionalState NewState);
    void CG_SetFcPeriphB(uint32_t Periph, FunctionalState NewState);



/** @} */
/* End of group CG_Exported_FunctionPrototype */

/** @} */
/* End of group CG */

/** @} */
/* End of group TX04_Periph_Driver */
#endif                          /*defined(__TMPM440_CG_H) */

#ifdef __cplusplus
}
#endif                          /* __cplusplus */
#endif                          /* __TMPM440_CG_H */
