/**
 *******************************************************************************
 * @file    tmpm440_ephc.h
 * @brief   This file provides all the functions prototypes for EPHC driver. 
 * @version V2.0.2.2
 * @date    2014/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __TMPM440_EPHC_H
#define __TMPM440_EPHC_H

#ifdef __cplusplus
extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "TMPM440.h"
#include "tx04_common.h"
#ifdef __IAR_SYSTEMS_ICC__
#if 1 != __LITTLE_ENDIAN__
#pragma bitfields=disjoint_types
#endif
#endif
/** @addtogroup TX04_Periph_Driver
  * @{
  */

/** @addtogroup EPHC
  * @{
  */

/** @defgroup EPHC_Exported_Types
  * @{
  */

/**
  * @brief EPHC Init Structure definition
  */

    typedef struct {
        uint32_t CountDownEdgeSelForP1; /*!< Count down edge selection */
        uint32_t CountUpEdgeSelForP1;   /*!< Count up edge selection */
        uint32_t InputClkSelection;     /*!< Input clock selection for 24-bit counter */
        uint32_t PhaseSelection;        /*!< Phase selection */
        uint32_t ModeSetting;   /*!< Mode setting */
        uint32_t DirectionSetting;      /*!< Direction setting */
        uint32_t NoiseFilterCtrl;       /*!< Select EPHC noise filter control */
        uint32_t CountClearCtrl;        /*!< Select EPHC counter clear control */
    } EPHC_InitTypeDef;

/**
  * @brief EPHC Interrupt factor Union definition
  */
#if defined ( __CC_ARM )
#ifdef __BIG_ENDIAN
    typedef union {
        uint32_t All;
        struct {
            uint32_t Reserverd:23;
            uint32_t CycleMeasurement:1;
            uint32_t IN1Rising:1;
            uint32_t IN0Rising:1;
            uint32_t IN1Falling:1;
            uint32_t IN0Falling:1;
            uint32_t UnderFlow:1;
            uint32_t OverFlow:1;
            uint32_t Compare1:1;
            uint32_t Compare0:1;
        } Bit;
    } EPHC_INTFactor;
#else
    typedef union {
        uint32_t All;
        struct {
            uint32_t Compare0:1;
            uint32_t Compare1:1;
            uint32_t OverFlow:1;
            uint32_t UnderFlow:1;
            uint32_t IN0Falling:1;
            uint32_t IN1Falling:1;
            uint32_t IN0Rising:1;
            uint32_t IN1Rising:1;
            uint32_t CycleMeasurement:1;
            uint32_t Reserverd:23;
        } Bit;
    } EPHC_INTFactor;
#endif
#elif  defined(__IAR_SYSTEMS_ICC__)
    typedef union {
        uint32_t All;
        struct {
            uint32_t Compare0:1;
            uint32_t Compare1:1;
            uint32_t OverFlow:1;
            uint32_t UnderFlow:1;
            uint32_t IN0Falling:1;
            uint32_t IN1Falling:1;
            uint32_t IN0Rising:1;
            uint32_t IN1Rising:1;
            uint32_t CycleMeasurement:1;
            uint32_t Reserverd:23;
        } Bit;
    } EPHC_INTFactor;
#endif

/** @} */
/* End of group EPHC_Exported_Types */

/** @defgroup EPHC_Exported_Constants
  * @{
  */

#define IS_EPHC_ALL_PERIPH(param)        (((param) == TSB_EPHC))

/* <EPHCxCNT> */
#define EPHC_CNT_MA1DN_NOCNTDOWN0            ((uint32_t)0x00000000)
#define EPHC_CNT_MA1DN_IN0RISING             ((uint32_t)0x00000001)
#define EPHC_CNT_MA1DN_IN1RISING             ((uint32_t)0x00000002)
#define EPHC_CNT_MA1DN_IN0FALLING            ((uint32_t)0x00000003)
#define EPHC_CNT_MA1DN_IN1FALLING            ((uint32_t)0x00000004)
#define EPHC_CNT_MA1DN_IN0BOTH               ((uint32_t)0x00000005)
#define EPHC_CNT_MA1DN_IN1BOTH               ((uint32_t)0x00000006)
#define EPHC_CNT_MA1DN_NOCNTDOWN7            ((uint32_t)0x00000007)
#define IS_EPHC_CNT_MA1DN(param)            (((param) == EPHC_CNT_MA1DN_NOCNTDOWN0) || \
                                            ((param) == EPHC_CNT_MA1DN_IN0RISING) || \
                                            ((param) == EPHC_CNT_MA1DN_IN1RISING) || \
                                            ((param) == EPHC_CNT_MA1DN_IN0FALLING) || \
                                            ((param) == EPHC_CNT_MA1DN_IN1FALLING) || \
                                            ((param) == EPHC_CNT_MA1DN_IN0BOTH) || \
                                            ((param) == EPHC_CNT_MA1DN_IN1BOTH) || \
                                            ((param) == EPHC_CNT_MA1DN_NOCNTDOWN7))

#define EPHC_CNT_MA1UP_NOCNTUP0              ((uint32_t)0x00000000)
#define EPHC_CNT_MA1UP_IN0RISING             ((uint32_t)0x00000010)
#define EPHC_CNT_MA1UP_IN1RISING             ((uint32_t)0x00000020)
#define EPHC_CNT_MA1UP_IN0FALLING            ((uint32_t)0x00000030)
#define EPHC_CNT_MA1UP_IN1FALLING            ((uint32_t)0x00000040)
#define EPHC_CNT_MA1UP_IN0BOTH               ((uint32_t)0x00000050)
#define EPHC_CNT_MA1UP_IN1BOTH               ((uint32_t)0x00000060)
#define EPHC_CNT_MA1UP_NOCNTUP7              ((uint32_t)0x00000070)
#define IS_EPHC_CNT_MA1UP(param)            (((param) == EPHC_CNT_MA1UP_NOCNTUP0) || \
                                            ((param) == EPHC_CNT_MA1UP_IN0RISING) || \
                                            ((param) == EPHC_CNT_MA1UP_IN1RISING) || \
                                            ((param) == EPHC_CNT_MA1UP_IN0FALLING) || \
                                            ((param) == EPHC_CNT_MA1UP_IN1FALLING) || \
                                            ((param) == EPHC_CNT_MA1UP_IN0BOTH) || \
                                            ((param) == EPHC_CNT_MA1UP_IN1BOTH) || \
                                            ((param) == EPHC_CNT_MA1UP_NOCNTUP7))


#define EPHC_CNT_BRCK_FC               ((uint32_t)0x00000000)
#define EPHC_CNT_BRCK_FC_2             ((uint32_t)0x00000100)
#define EPHC_CNT_BRCK_FC_4             ((uint32_t)0x00000200)
#define EPHC_CNT_BRCK_FC_8             ((uint32_t)0x00000300)
#define IS_EPHC_CNT_BRCK(param)       (((param) == EPHC_CNT_BRCK_FC) || \
                                       ((param) == EPHC_CNT_BRCK_FC_2) || \
                                       ((param) == EPHC_CNT_BRCK_FC_4) || \
                                       ((param) == EPHC_CNT_BRCK_FC_8))

#define EPHC_CNT_PBDIR_POSITIVEPHASE          ((uint32_t)0x00000000)
#define EPHC_CNT_PBDIR_NEGATIVEPHASE          ((uint32_t)0x00000800)
#define IS_EPHC_CNT_PBDIR_PHASESEL(param)    (((param) == EPHC_CNT_PBDIR_POSITIVEPHASE) || \
                                              ((param) == EPHC_CNT_PBDIR_NEGATIVEPHASE))

#define EPHC_CNT_MA12_PULSE_2                 ((uint32_t)0x00000000)
#define EPHC_CNT_MA12_PULSE_1                 ((uint32_t)0x00001000)
#define IS_EPHC_CNT_MA12_PULSEMODE(param)    (((param) == EPHC_CNT_MA12_PULSE_2) || \
                                              ((param) == EPHC_CNT_MA12_PULSE_1))

#define EPHC_CNT_MA2DIR_POSITIVEDIR              ((uint32_t)0x00000000)
#define EPHC_CNT_MA2DIR_NEGATIVEDIR              ((uint32_t)0x00002000)
#define IS_EPHC_CNT_MA2DIR_DIRSETTING(param)    (((param) == EPHC_CNT_MA2DIR_POSITIVEDIR) || \
                                                 ((param) == EPHC_CNT_MA2DIR_NEGATIVEDIR))

#define EPHC_CNT_NOISEFILTER_NONE           ((uint32_t)0x00000000)
#define EPHC_CNT_NOISEFILTER_2              ((uint32_t)0x00004000)
#define EPHC_CNT_NOISEFILTER_4              ((uint32_t)0x00008000)
#define IS_EPHC_CNT_NOISEFILTER(param)    (((param) == EPHC_CNT_NOISEFILTER_NONE) || \
                                           ((param) == EPHC_CNT_NOISEFILTER_2) || \
                                           ((param) == EPHC_CNT_NOISEFILTER_4))


/* <EPHCxIE> */
#define EPHC_IE_INT_PCCP0                ((uint32_t)0x00000001)
#define EPHC_IE_INT_PCCP1                ((uint32_t)0x00000002)
#define EPHC_IE_INT_PCOVF                ((uint32_t)0x00000004)
#define EPHC_IE_INT_PCUDF                ((uint32_t)0x00000008)
#define EPHC_IE_INT_PCDT0                ((uint32_t)0x00000010)
#define EPHC_IE_INT_PCDT1                ((uint32_t)0x00000020)
#define EPHC_IE_INT_PCDT2                ((uint32_t)0x00000040)
#define EPHC_IE_INT_PCDT3                ((uint32_t)0x00000080)
#define EPHC_IE_INT_PCDIR                ((uint32_t)0x00000100)
#define EPHC_IE_INT_PCUOVF               ((uint32_t)0x00000200)
#define EPHC_IE_INT_ALL                  (EPHC_IE_INT_PCCP0 | \
                                          EPHC_IE_INT_PCCP1 | \
                                          EPHC_IE_INT_PCOVF | \
                                          EPHC_IE_INT_PCUDF | \
                                          EPHC_IE_INT_PCDT0 | \
                                          EPHC_IE_INT_PCDT1 | \
                                          EPHC_IE_INT_PCDT2 | \
                                          EPHC_IE_INT_PCDT3 | \
                                          EPHC_IE_INT_PCDIR | \
                                          EPHC_IE_INT_PCUOVF)
#define IS_EPHC_INT_ENABLE(param)        (((param) >= EPHC_IE_INT_PCCP0) && ((param) <= EPHC_IE_INT_ALL))
#define IS_EPHC_INT_DISABLE              IS_EPHC_INT_ENABLE

/* <EPHCxFLG> */
#define EPHC_FLG_CMP0F                    ((uint32_t)0x00000001)
#define EPHC_FLG_CMP1F                    ((uint32_t)0x00000002)
#define EPHC_FLG_OVFF                     ((uint32_t)0x00000004)
#define EPHC_FLG_UBFF                     ((uint32_t)0x00000008)
#define EPHC_FLG_SB0F                     ((uint32_t)0x00000010)
#define EPHC_FLG_SB1F                     ((uint32_t)0x00000020)
#define EPHC_FLG_SB2F                     ((uint32_t)0x00000040)
#define EPHC_FLG_SB3F                     ((uint32_t)0x00000080)
#define EPHC_FLG_DIRF                     ((uint32_t)0x00000100)
#define EPHC_FLG_ALL                      (EPHC_FLG_CMP0F | \
                                           EPHC_FLG_CMP1F | \
                                           EPHC_FLG_OVFF | \
                                           EPHC_FLG_UBFF | \
                                           EPHC_FLG_SB0F | \
                                           EPHC_FLG_SB1F | \
                                           EPHC_FLG_SB2F | \
                                           EPHC_FLG_SB3F | \
                                           EPHC_FLG_DIRF)
#define IS_EPHC_FLG(param)                (((param) >= EPHC_FLG_CMP0F) && ((param) <= EPHC_FLG_ALL))

/* <EPHCxARUN> */
#define EPHC_RUN                         ((uint8_t)0x01)
#define EPHC_STOP                        ((uint8_t)0x00)
#define IS_EPHC_CMD(param)               (((param) == EPHC_RUN) || ((param) == EPHC_STOP))

#define EPHC_COUNT_CONTINUE              ((uint32_t)0x00000000)
#define EPHC_COUNT_CLR                   ((uint32_t)0x00000002)
#define IS_EPHC_COUNT_CTRL(param)        (((param) == EPHC_COUNT_CONTINUE) || ((param) == EPHC_COUNT_CLR))

/* <EPHCxACP0, EPHCxACP1> */
#define IS_EPHC_CMP_VALUE(param)         ((param) <= 0x0000FFFFU)

#define EPHC_COMP_0                      ((uint8_t)0x00)
#define EPHC_COMP_1                      ((uint8_t)0x01)
#define IS_EPHC_COMP_REG(param)          (((param) == EPHC_COMP_0) || ((param) == EPHC_COMP_1))


/* <EPHCxADAT> */
#define IS_EPHC_ADAT_VALUE(param)         ((param) <= 0x0000FFFFU)

/* <EPHCxBRUN> */
#define EPHC_BRUN                         ((uint8_t)0x01)
#define EPHC_BSTOP                        ((uint8_t)0x00)
#define IS_EPHC_BCMD(param)               (((param) == EPHC_BRUN) || ((param) == EPHC_BSTOP))

/* <EPHCxBDMA> */
#define EPHC_DMA_REQ_CAPTURE_0            ((uint8_t)0x01)
#define IS_EPHC_DMA_REQ(param)            ((param) == EPHC_DMA_REQ_CAPTURE_0)

/* <EPHCxBUC> */
#define IS_EPHC_T24UCR_VALUE(param)         ((param) <= 0x00FFFFFFU)

/* <EPHCxBCAP00,EPHCxBCAP10,EPHCxBCAP20,EPHCxBCAP30> */
#define EPHC_BCAP00_IN0RISING                      ((uint8_t)0x00)
#define EPHC_BCAP10_IN1RISING                      ((uint8_t)0x01)
#define EPHC_BCAP20_IN0FALLING                     ((uint8_t)0x02)
#define EPHC_BCAP30_IN1FALLING                     ((uint8_t)0x03)
#define IS_EPHC_BCAP_REG(param)                   (((param) == EPHC_BCAP00_IN0RISING) || \
                                                   ((param) == EPHC_BCAP10_IN1RISING) || \
                                                   ((param) == EPHC_BCAP20_IN0FALLING) || \
                                                   ((param) == EPHC_BCAP30_IN1FALLING))

/* <EPHCxB0DAT,EPHCxB1DAT,EPHCxB2DAT,EPHCxB3DAT,EPHCxBCDAT> */
#define EPHC_B0DAT_IN0RISING                      ((uint8_t)0x00)
#define EPHC_B1DAT_IN1RISING                      ((uint8_t)0x01)
#define EPHC_B2DAT_IN0FALLING                     ((uint8_t)0x02)
#define EPHC_B3DAT_IN1FALLING                     ((uint8_t)0x03)
#define EPHC_BCDAT_COMMON                         ((uint8_t)0x04)
#define IS_EPHC_BDAT_REG(param)                   (((param) == EPHC_B0DAT_IN0RISING) || \
                                                   ((param) == EPHC_B1DAT_IN1RISING) || \
                                                   ((param) == EPHC_B2DAT_IN0FALLING) || \
                                                   ((param) == EPHC_B3DAT_IN1FALLING) || \
                                                   ((param) == EPHC_BCDAT_COMMON))
/* <EPHCxB0PDT,EPHCxB1PDT,EPHCxB2PDT,EPHCxB3PDT> */
#define EPHC_B0PDT                      ((uint8_t)0x00)
#define EPHC_B1PDT                      ((uint8_t)0x01)
#define EPHC_B2PDT                      ((uint8_t)0x02)
#define EPHC_B3PDT                      ((uint8_t)0x03)
#define IS_EPHC_BPDT_REG(param)        (((param) == EPHC_B0PDT) || \
                                        ((param) == EPHC_B1PDT) || \
                                        ((param) == EPHC_B2PDT) || \
                                        ((param) == EPHC_B3PDT))

/** @} */
/* End of EPHC_Exported_Constants */

/** @defgroup EPHC_Exported_FunctionPrototypes
  * @{
  */
    void EPHC_Enable(TSB_EPHC_TypeDef * EPHCx);
    void EPHC_Disable(TSB_EPHC_TypeDef * EPHCx);
    void EPHC_Init(TSB_EPHC_TypeDef * EPHCx, EPHC_InitTypeDef * InitStruct);
    void EPHC_EnableInterrupt(TSB_EPHC_TypeDef * EPHCx, uint32_t EnableINT);
    void EPHC_DisableInterrupt(TSB_EPHC_TypeDef * EPHCx, uint32_t DisableINT);
    EPHC_INTFactor EPHC_GetINTFactor(TSB_EPHC_TypeDef * EPHCx);
    void EPHC_ClearINTFactor(TSB_EPHC_TypeDef * EPHCx, uint32_t ClearINT);
    void EPHC_ASetRunState(TSB_EPHC_TypeDef * EPHCx, uint8_t Cmd);
    void EPHC_AClearPulseCntValue(TSB_EPHC_TypeDef * EPHCx);
    uint16_t EPHC_AGetCompareValue(TSB_EPHC_TypeDef * EPHCx, uint8_t CmpReg);
    void EPHC_ASetCompareValue(TSB_EPHC_TypeDef * EPHCx, uint8_t CmpReg, uint16_t CmpValue);
    uint16_t EPHC_AGetPulseCntValue(TSB_EPHC_TypeDef * EPHCx);
    void EPHC_BSetRunState(TSB_EPHC_TypeDef * EPHCx, uint8_t Cmd);
    void EPHC_BSetDMAReq(TSB_EPHC_TypeDef * EPHCx, FunctionalState NewState, uint8_t DMAReq);
    uint32_t EPHC_BGetReadCntValue(TSB_EPHC_TypeDef * EPHCx);
    uint32_t EPHC_BGetCapRegValue(TSB_EPHC_TypeDef * EPHCx, uint8_t CapReg);
    uint32_t EPHC_BGetCapRegOverflow(TSB_EPHC_TypeDef * EPHCx, uint8_t CapReg);
    uint32_t EPHC_BGetCycleCntRegValue(TSB_EPHC_TypeDef * EPHCx, uint8_t CntReg);
    uint32_t EPHC_BGetPhaseDiffRegValue(TSB_EPHC_TypeDef * EPHCx, uint8_t PhaseReg);
/** @} */
/* End of EPHC_Exported_FunctionPrototypes */

/** @} */
/* End of group EPHC */

/** @} */
/* End of group TX04_Periph_Driver */
#ifdef __cplusplus
}
#endif                          /* __cplusplus */
#endif                          /* __TMPM440_EPHC_H */
