/**
 *******************************************************************************
 * @file    tmpm440_kscan.h
 * @brief   This file provides all the functions prototypes for Key Scan driver. 
 * @version V2.0.2.2
 * @date    2014/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __TMPM440_KSCAN_H
#define __TMPM440_KSCAN_H

#ifdef __cplusplus
extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "TMPM440.h"
#include "tx04_common.h"

/** @addtogroup TX04_Periph_Driver
  * @{
  */

/** @addtogroup KSCAN
  * @{
  */

#define KSCAN_KSCL_FS           0U
#define KSCAN_KSCL_TBOUT        1U

#define IS_KSCAN_KSCLK(param)           (((param) == KSCAN_KSCL_FS)|| \
                                        ((param) == KSCAN_KSCL_TBOUT))

#define KSCAN_CH_0                      ((uint8_t)0x01)
#define KSCAN_CH_1                      ((uint8_t)0x02)
#define KSCAN_CH_2                      ((uint8_t)0x04)
#define KSCAN_CH_3                      ((uint8_t)0x08)
#define KSCAN_CH_4                      ((uint8_t)0x10)
#define KSCAN_CH_5                      ((uint8_t)0x20)
#define KSCAN_CH_6                      ((uint8_t)0x40)
#define KSCAN_CH_7                      ((uint8_t)0x80)
#define KSCAN_CH_ALL                    ((uint8_t)0xFF)
#define IS_KSCAN_INOUTCH(param)         ((param) > 0U)

#define IS_KSCAN_CH(param)              ((param) <= 7U)

#define IS_KSCAN_MASKBIT(param)         ((param) > 0U)

#define IS_KSCAN_STROBECYCLE(param)         ((param) > 0U)

#define LOW_OUTPUT              2U
#define STROBE_OUTPUT           1U
#define HIGH_OUTPUT             0U
#define IS_KSCAN_OUTPUTTYPE(param)      (((param) == LOW_OUTPUT)|| \
                                         ((param) == STROBE_OUTPUT)|| \
                                         ((param) == HIGH_OUTPUT))
#define KSCAN_MATCH_2C          0U
#define KSCAN_MATCH_4C          1U
#define IS_KSCAN_MATCH(param)           (((param) == KSCAN_MATCH_2C)|| \
                                         ((param) == KSCAN_MATCH_4C))
#define IS_KSCAN_STROBEWIDTH(param)     ((param) <= 5U)

/** @defgroup KSCAN_Exported_FunctionPrototypes
  * @{
  */
    void KSCAN_Enable(void);
    void KSCAN_Disable(void);
    void KSCAN_SetSCLK(uint8_t ksclk);
    void KSCAN_SetInputCtrlMask(uint8_t InputCH, FunctionalState NewState);
    void KSCAN_SetOutputCtrl(uint8_t OutputCH, FunctionalState NewState);
    void KSCAN_SetStrobeOutput(uint8_t cycle);
    void KSCAN_Start(void);
    void KSCAN_Stop(void);
    uint8_t KSCAN_ReadStart(void);
    void KSCAN_KSBRInitial(void);
    void KSCAN_SWReset(void);
    void KSCAN_SetConsecutiveMatches(uint8_t match);
    void KSCAN_SetChatCancelTime(uint8_t timeN);
    void KSCAN_SetStrobeWidth(uint8_t StrobeWidth);
    uint8_t KSCAN_ReadBufChecked(uint8_t output);
    void KSCAN_MaskReadBuf(uint32_t MaskCH, uint32_t MaskBit, FunctionalState NewState);
    void KSCAN_SetINTReq(FunctionalState NewState);

/** @} */
/* End of KSCAN_Exported_FunctionPrototypes */

/** @} */
/* End of group KSCAN */

/** @} */
/* End of group TX04_Periph_Driver */
#ifdef __cplusplus
}
#endif                          /* __cplusplus */
#endif                          /* __TMPM440_KSCAN_H */
