/**
 *******************************************************************************
 * @file    tmpm440_tmrc.h
 * @brief   This file provides all the functions prototypes for TMRC driver.
 * @version V2.0.2.3
 * @date    2014/05/20
 *
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 *
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __TMPM440_TMRC_H
#define __TMPM440_TMRC_H

#ifdef __cplusplus
extern "C" {
#endif                          /* __cplusplus */

/* Includes ------------------------------------------------------------------*/
#include "TMPM440.h"
#include "tx04_common.h"

#if defined(__TMPM440_TMRC_H)
/** @addtogroup TX04_Periph_Driver
  * @{
  */

/** @addtogroup TMRC
  * @{
  */

/** @defgroup TMRC_Exported_Types
  * @{
  */

/**
  * @brief EPHC Init Structure definition
  */

/** @} */
/* End of group TMRC_Exported_Types */

/** @defgroup TMRC_Exported_Constants
  * @{
  */

#define IS_TMRC_ALL_PERIPH(param)    ((param) == TSB_TC)

#define TMRC_RUN                     ((uint32_t)0x00000001)
#define TMRC_STOP                    ((uint32_t)0x00000000)
#define IS_TMRC_CMD(param)           (((param) == TMRC_RUN) || ((param) == TMRC_STOP))

#define TMRC_CLK_DIV_4               ((uint32_t)0x00000000)
#define TMRC_CLK_DIV_8               ((uint32_t)0x00000001)
#define TMRC_CLK_DIV_16              ((uint32_t)0x00000002)
#define TMRC_CLK_DIV_32              ((uint32_t)0x00000003)
#define TMRC_CLK_DIV_64              ((uint32_t)0x00000004)
#define TMRC_CLK_DIV_128             ((uint32_t)0x00000005)
#define TMRC_CLK_DIV_256             ((uint32_t)0x00000006)
#define TMRC_CLK_DIV_512             ((uint32_t)0x00000007)
#define TMRC_CLK_TCTBT_IN            ((uint32_t)0x0000000F)
#define IS_TMRC_CLK_DIV(param)       (((param) == TMRC_CLK_DIV_4) || \
                                      ((param) == TMRC_CLK_DIV_8) || \
                                      ((param) == TMRC_CLK_DIV_16) || \
                                      ((param) == TMRC_CLK_DIV_32) || \
                                      ((param) == TMRC_CLK_DIV_64) || \
                                      ((param) == TMRC_CLK_DIV_128) || \
                                      ((param) == TMRC_CLK_DIV_256) || \
                                      ((param) == TMRC_CLK_DIV_512) || \
                                      ((param) == TMRC_CLK_TCTBT_IN))

    typedef enum {
        TMRC_CMP_0 = 0U,
        TMRC_CMP_1 = 1U,
        TMRC_CMP_2 = 2U,
        TMRC_CMP_3 = 3U,
        TMRC_CMP_4 = 4U,
        TMRC_CMP_5 = 5U,
        TMRC_CMP_6 = 6U,
        TMRC_CMP_7 = 7U
    } TMRC_CMPReg;

#define IS_TMRC_CMP_REG(param)     (((param) == TMRC_CMP_0) || \
                                      ((param) == TMRC_CMP_1) || \
                                      ((param) == TMRC_CMP_2) || \
                                      ((param) == TMRC_CMP_3) || \
                                      ((param) == TMRC_CMP_4) || \
                                      ((param) == TMRC_CMP_5) || \
                                      ((param) == TMRC_CMP_6) || \
                                      ((param) == TMRC_CMP_7))

    typedef enum {
        TMRC_FF_REVERSE_TRG_DISABLE = 0U,
        TMRC_FF_REVERSE_TRG_ENABLE = 1U
    } TMRC_FFReverseTrg;
#define IS_TMRC_FF_REVERSE_TRG(param)     (((param) == TMRC_FF_REVERSE_TRG_DISABLE) || \
                                                ((param) == TMRC_FF_REVERSE_TRG_ENABLE))
    typedef enum {
        TMRC_FLIPFLOP_INVERT = 0U,
        TMRC_FLIPFLOP_SET = 1U,
        TMRC_FLIPFLOP_CLEAR = 2U
    } TMRC_FlipFlopCtrl;
#define IS_TMRC_FLIPFLOP_CTRL(param) (((param) == TMRC_FLIPFLOP_INVERT) || \
                                      ((param) == TMRC_FLIPFLOP_SET) || \
                                      ((param) == TMRC_FLIPFLOP_CLEAR))

    typedef enum {
        TMRC_CMP_DB_DISABLE = 0U,
        TMRC_CMP_DB_ENABLE = 1U
    } TMRC_CMPDBCtrl;
#define IS_TMRC_CMP_DB_CTRL(param)     (((param) == TMRC_CMP_DB_DISABLE) || \
                                        ((param) == TMRC_CMP_DB_ENABLE))

    typedef enum {
        TMRC_CMP_MATCH_DISABLE = 0U,
        TMRC_CMP_MATCH_ENABLE = 1U
    } TMRC_CMPMatch;
#define IS_TMRC_CMP_MATCH(param)     (((param) == TMRC_CMP_MATCH_DISABLE) || \
                                          ((param) == TMRC_CMP_MATCH_ENABLE))

    typedef struct {
        TMRC_CMPReg CMPReg;     /*!< Compare register number */
        TMRC_FFReverseTrg FFReverseTrg; /*!< Specify TMRC flip-flop reverse trigger */
        TMRC_FlipFlopCtrl FlipFlopCtrl; /*!< Select TMRC flip-flop output level */
        TMRC_CMPDBCtrl CMPDBCtrl;       /*!< Double buffer of compare register */
        TMRC_CMPMatch CMPMatch; /*!< Compare match detection */
    } TMRC_CMPConfigTypeDef;

    typedef enum {
        TMRC_CAP_0 = 0U,
        TMRC_CAP_1 = 1U,
        TMRC_CAP_2 = 2U,
        TMRC_CAP_3 = 3U
    } TMRC_CAPReg;

#define IS_TMRC_CAP_REG(param)     (((param) == TMRC_CAP_0) || \
                                    ((param) == TMRC_CAP_1) || \
                                    ((param) == TMRC_CAP_2) || \
                                    ((param) == TMRC_CAP_3))

    typedef enum {
        TMRC_NOFILTER = 0U,
        TMRC_FILTER = 1U
    } TMRC_NoiseFilter;
#define IS_TMRC_NOISE_FILTER(param) (((param) == TMRC_NOFILTER) || \
                                     ((param) == TMRC_FILTER))

    typedef enum {
        TMRC_NO_CAPTURE = 0U,
        TMRC_IN_RISING_EDGE = 1U,
        TMRC_IN_FALLING_EDGE = 2U,
        TMRC_IN_BOTH_EDGE = 3U
    } TMRC_ValidEdgeSel;
#define IS_TMRC_VALID_EDGE_SEL(param)      (((param) == TMRC_NO_CAPTURE) || \
                                            ((param) == TMRC_IN_RISING_EDGE) || \
                                            ((param) == TMRC_IN_FALLING_EDGE) || \
                                            ((param) == TMRC_IN_BOTH_EDGE))

    typedef struct {
        TMRC_CAPReg CAPReg;     /*!< Capture register number */
        TMRC_NoiseFilter NoiseFilter;   /*!< Noise filter control for TCIN0 to 3 pin input */
        TMRC_ValidEdgeSel ValidEdgeSel; /*!< Valid edge selection for TCIN0 to 3 input */
    } TMRC_CAPConfigTypeDef;


#define IS_TMRC_CMPVAL(param)                   ((param) <= (uint32_t)0xFFFFFFFF)

/** @} */
/* End of group TMRC_Exported_Constants */
/** @defgroup TMRC_Exported_FunctionPrototypes
  * @{
  */
    void TMRC_Enable(TSB_TC_TypeDef * TCx);
    void TMRC_Disable(TSB_TC_TypeDef * TCx);
    void TMRC_SetRunState(TSB_TC_TypeDef * TCx, uint32_t Cmd);
    void TMRC_SetIdleMode(TSB_TC_TypeDef * TCx, FunctionalState NewState);
    void TMRC_ExecuteSWCapture(TSB_TC_TypeDef * TCx);
    void TMRC_SetSrcClk(TSB_TC_TypeDef * TCx, uint32_t ClkDiv);
    void TMRC_SetNoiseFilter(TSB_TC_TypeDef * TCx, TMRC_NoiseFilter NosFlt);
    uint32_t TMRC_GetSWCaptureValue(TSB_TC_TypeDef * TCx);
    uint32_t TMRC_GetReadCaptureValue(TSB_TC_TypeDef * TCx);
    void TMRC_CMPRegConfig(TSB_TC_TypeDef * TCx, TMRC_CMPConfigTypeDef * CMPConfigStruct);
    void TMRC_SetCMPRegValue(TSB_TC_TypeDef * TCx, TMRC_CMPReg CMPRegNum, uint32_t CMPRegVal);
    uint32_t TMRC_GetCMPRegValue(TSB_TC_TypeDef * TCx, TMRC_CMPReg CMPRegNum);
    void TMRC_CAPRegConfig(TSB_TC_TypeDef * TCx, TMRC_CAPConfigTypeDef * CAPConfigStruct);
    uint32_t TMRC_GetCntCaptureValue(TSB_TC_TypeDef * TCx, TMRC_CAPReg CAPRegNum);

/** @} */
/* End of group TMRC_Exported_FunctionPrototypes */

/** @} */
/* End of group TMRC */

/** @} */
/* End of group TX04_Periph_Driver */
#endif                          /* defined(__TMPM440_TMRC_H) */

#ifdef __cplusplus
}
#endif                          /* __cplusplus */
#endif                          /* __TMPM440_TMRC_H */
