/**
 *******************************************************************************
 * @file    adc.c
 * @brief   all interrupt request functions definition of ADC_Data_Read demo 
 *          for the TOSHIBA 'TMPM440' Device Series 
 * @version V0.101
 * @date    2014/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */
/* Includes ------------------------------------------------------------------*/
#include "adc.h"

/**
  * @brief  Initialize ADC register and variables
  * @param  None
  * @retval None
  */
void ADC_Init(void)
{
    /* Enable ADC clock supply */
    CG_SetPLL1ForADC(ENABLE);

    /* set ADC clock */
    ADC_SetClk(TSB_ADA, ADC_CONVERSION_CLK_80, ADC_FC_DIVIDE_LEVEL_8);

    /* select ADC input channel */
    ADC_SetInputChannel(TSB_ADA, ADC_AN_01);

    /* Enable ADC repeat mode */
    ADC_SetRepeatMode(TSB_ADA, ENABLE);

    /* Set interrupt mode */
    ADC_SetINTMode(TSB_ADA, ADC_INT_CONVERSION_8);

    /* Turn VREF on */
    ADC_SetVref(TSB_ADA, ENABLE);

    /* Wait at least 3us to ensure the voltage is stable */
    Delay(10U);
}

/**
  * @brief  Display the voltage change in LEDs.
  * @param  None
  * @retval None
  */
void ADC_Display(void)
{
    uint8_t tmp = 0U;
    ADC_Result result = ADC_GetConvertResult(TSB_ADA, ADC_REG_00);

    tmp = result.Bit.ADResult / 455U;    /*the max value of result is 4095 */
    LED_Off(LED_ALL);

    switch (tmp) {
    case 0x01U:
        LED_On(LED0);
        break;
    case 0x02U:
        LED_On(LED0 | LED1);
        break;
    case 0x03U:
        LED_On(LED0 | LED1 | LED2);
        break;
    case 0x04U:
        LED_On(LED0 | LED1 | LED2 | LED3);
        break;
    case 0x05U:
        LED_On(LED0 | LED1 | LED2 | LED3 | LED4);
        break;
    case 0x06U:
        LED_On(LED0 | LED1 | LED2 | LED3 | LED4 | LED5);
        break;
    case 0x07U:
        LED_On(LED0 | LED1 | LED2 | LED3 | LED4 | LED5 | LED6);
        break;
    case 0x08U:
        LED_On(LED0 | LED1 | LED2 | LED3 | LED4 | LED5 | LED6 | LED7);
        break;
    default:
        break;
    }
}

void Delay(int time)
{
    volatile int i = 0U;

    for (i = 0U; i < (time * 800U); ++i);
}
