/**
 *******************************************************************************
 * @file	main.c
 * @brief	the application functions of STOP2_KSCAN demo for the TOSHIBA
 *			'TMPM440' Device Series 
 * @version V0.102
 * @date	2014/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */

#include "tmpm440_kscan.h"
#include "tmpm440_gpio.h"
#include "tmpm440_cg.h"
#include "sw.h"
#include  "led.h"

/* for CG */
#define WARMTIME			0xC35U

void configCG_FS(unsigned short time);
void configGPIO_KSCAN(FunctionalState newStateIPUP, FunctionalState newStateOD);
void configKSCAN(void);
int isStanbyRelease(void);
void enterSTOP2(void);
void configSTOP2(void);
void startKSCAN(FunctionalState newState);

/**
  * @brief  The main function of demo
  * @param  None
  * @retval None
  */
int main(void)
{
    SW_Init();
    LED_Init();

    configGPIO_KSCAN(ENABLE, DISABLE);  /* Set KSCAN's GPIO */

    /* after release standby mode */
    if (isStanbyRelease()) {

        CG_SetSTBYReleaseINTSrc(CG_INT_SRC_INTKSCAN, CG_INT_ACTIVE_STATE_RISING, DISABLE);

        NVIC_EnableIRQ(INTKSCAN_IRQn);

        CG_SetPortKeepInStop2Mode(DISABLE);
    }
    /* Initialize the KSCAN after reset */
    else {

        configCG_FS(WARMTIME);

        KSCAN_SetSCLK(KSCAN_KSCL_FS);   /*select fs for ksclk */

        configKSCAN();          /* KSCAN initial */

        CG_ClearINTReq(CG_INT_SRC_INTKSCAN);
        NVIC_ClearPendingIRQ(INTKSCAN_IRQn);

        NVIC_EnableIRQ(INTKSCAN_IRQn);

        KSCAN_SetINTReq(ENABLE);

        startKSCAN(ENABLE);
    }

    LED_On(LED7);
    while (1U) {
        if (SW_Get(SW0) == 0U) {

            LED_Off(LED7);      /* LED7 is off before enter stop2 */

            enterSTOP2();
        }
    }
}
/**
  * @brief  Enter the STOP2 low power mode
  * @param  None
  * @retval None
  */
  
void enterSTOP2(void)
{
    CG_SetSTBYReleaseINTSrc(CG_INT_SRC_INTKSCAN, CG_INT_ACTIVE_STATE_RISING, ENABLE);

    configSTOP2();

    __DSB();
    __WFI();
}

/**
  * @brief  ExtINTSrc_IRQHandler
  * @param  None
  * @retval None
  */
void INTKSCAN_IRQHandler(void)
{
    uint8_t ledval;

    CG_ClearINTReq(CG_INT_SRC_INTKSCAN);

    ledval = LED7;              /* Normal mode:: LED7 is ON */
    ledval |= (~(KSCAN_ReadBufChecked(0U))) & GPIO_BIT_0;       /* KSOUT0xKSIN0 */
    ledval |= (~(KSCAN_ReadBufChecked(1U))) & GPIO_BIT_1;       /* KSOUT1xKSIN1 */
    ledval |= (~(KSCAN_ReadBufChecked(2U))) & GPIO_BIT_2;       /* KSOUT2xKSIN2 */

    LED_On(ledval);
    LED_Off(~ledval);
}

#ifdef DEBUG
void assert_failed(char *file, int32_t line)
{
    while (1U) {
        __NOP();
    }
}
#endif
