/**
 *******************************************************************************
 * @file    main.c
 * @brief   the application functions of EXB demo for the 
 *          TOSHIBA 'TMPM440' Device Series 
 * @version V0.101
 * @date    2014/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */
#include <string.h>
#include "tmpm440_exb.h"
#include "tmpm440_gpio.h"

#define SRAM_RW

#ifdef SRAM_RW
#define TEST_DATA_LEN           ((uint16_t)0x0010)
#define EXB_SRAM_START_ADDR     ((uint32_t)0x60000000)

void EXB_GPIOConfig(void);
volatile Result rw_result = ERROR;
#endif
/*******************************************************************************
* Function Name  : main
* Description    : main function:demo for external 16-bit SRAM, separate bus mode
* Input          : None.
* Return         : None.
*******************************************************************************/
   
	
int main(void)
{
    uint32_t w_data[TEST_DATA_LEN] = { 0U };
    uint32_t r_data[TEST_DATA_LEN] = { 0U };
    uint16_t rw_cnt = 0U;
    uint32_t addr = 0U;
    uint8_t chip = EXB_CS0;
    uint8_t BusMode = EXB_BUS_SEPARATE;        /* Address bus and data bus are separate */
    uint8_t Cycle = EXB_CYCLE_NONE;
    /* Initial process demo */

#ifdef SRAM_RW
  
    uint16_t i = 0U;
	EXB_InitTypeDef InitStruct = { 0U };
#endif

    InitStruct.AddrSpaceSize = EXB_1M_BYTE;
    InitStruct.StartAddr = 0x00U;
    InitStruct.BusWidth = EXB_BUS_WIDTH_BIT_16;
    /* Set cycles time according to AC timing of SRAM datasheet,base clock: EXBCLK(fsys) */
    InitStruct.Cycles.InternalWait = EXB_INTERNAL_WAIT_4;
    InitStruct.Cycles.ReadSetupCycle = EXB_CYCLE_1;
    InitStruct.Cycles.WriteSetupCycle = EXB_CYCLE_1;
    InitStruct.Cycles.ALEWaitCycle = EXB_CYCLE_1;
    InitStruct.Cycles.ReadRecoveryCycle = EXB_CYCLE_1;
    InitStruct.Cycles.WriteRecoveryCycle = EXB_CYCLE_1;
    InitStruct.Cycles.ChipSelectRecoveryCycle = EXB_CYCLE_1;

#ifdef SRAM_RW
    EXB_GPIOConfig();
	
#endif

    EXB_SetBusMode(BusMode);
    EXB_SetBusCycleExtension(Cycle);
    EXB_Init(chip, &InitStruct);
    EXB_Enable(chip);

#ifdef SRAM_RW
    /* SRAM Read/Write demo */
    addr = (((uint32_t) InitStruct.StartAddr<<16U) | EXB_SRAM_START_ADDR);

    for (i = 0U; i < TEST_DATA_LEN; i++) {
        w_data[i] = i;
    }
	
    rw_cnt = TEST_DATA_LEN * sizeof(w_data[0]);

    memcpy((uint32_t *)addr, w_data, (uint32_t) rw_cnt);
    __DSB();
    memcpy(r_data, (uint32_t *)addr, (uint32_t) rw_cnt);

    /* check rw_result to see if SRAM write/read is sucessful or not */
   if (memcmp(w_data, r_data, (uint32_t) rw_cnt) == 0) {
        rw_result = SUCCESS;
    } else {
        rw_result = ERROR;
    }
#endif
    while (1) {
        /* Do nothing */
    }
}

#ifdef SRAM_RW
/**
  * @brief  Configure GPIO to EXB
  * @param  None
  * @retval None
  */
void EXB_GPIOConfig(void)
{
  	/*Data D0~D7  config*/
   	GPIO_SetInputEnableReg(GPIO_PA,GPIO_BIT_ALL, ENABLE);         /*input mode*/
	GPIO_EnableFuncReg(GPIO_PA, GPIO_FUNC_REG_1, GPIO_BIT_ALL);   /*ebif data bus func*/
    GPIO_SetOutputEnableReg(GPIO_PA,GPIO_BIT_ALL, ENABLE);        /*Onput mode*/
	/*Data D8~D15  config*/
   	GPIO_SetInputEnableReg(GPIO_PB,GPIO_BIT_ALL, ENABLE);         /*input mode*/
	GPIO_EnableFuncReg(GPIO_PB, GPIO_FUNC_REG_1, GPIO_BIT_ALL);   /*ebif data bus func*/
	GPIO_SetOutputEnableReg(GPIO_PB,GPIO_BIT_ALL, ENABLE);        /*Onput mode*/
	
	
	/*Address A0-A7 config*/
  	GPIO_SetOutputEnableReg(GPIO_PC,GPIO_BIT_ALL, ENABLE);        /*output mode*/
	GPIO_EnableFuncReg(GPIO_PC, GPIO_FUNC_REG_1, GPIO_BIT_ALL);   /*ebif addr bus func*/
	/*Address A8-A15 config*/
  	GPIO_SetOutputEnableReg(GPIO_PD,GPIO_BIT_ALL, ENABLE);        /*output mode*/
	GPIO_EnableFuncReg(GPIO_PD, GPIO_FUNC_REG_1, GPIO_BIT_ALL);   /*ebif addr bus func*/
	/*Address A16-A23 config*/
  	GPIO_SetOutputEnableReg(GPIO_PE,GPIO_BIT_ALL, ENABLE);        /*output mode*/
	GPIO_EnableFuncReg(GPIO_PE, GPIO_FUNC_REG_1, GPIO_BIT_ALL);   /*ebif addr bus func*/

	/*CTL BUS CONF*/
    GPIO_SetOutputEnableReg(GPIO_PF,0x6FU, ENABLE);               /*output mode*/
	GPIO_EnableFuncReg(GPIO_PF, GPIO_FUNC_REG_1, 0x6FU);          /*ebif CTL bus func*/
	
  
}
#endif

#ifdef DEBUG
void assert_failed(char *file, int32_t line)
{
    while (1) {
        __NOP();
    }
}
#endif
