/**
********************************************************************************
 * @file   main.c
 * @brief  the application functions of KWUP demo for the TOSHIBA
             'TMPM440' Device Series 
 * @version V0.103
 * @date    2014/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */
/* Includes ------------------------------------------------------------------*/
#include "tmpm440_kwup.h"
#include "tmpm440_cg.h"
#include "led.h"

#define CG_INT_SRC_KWUP 22U

/* for MCU */
void __WFI_wait()
{
    __WFI();
    __NOP();
    __NOP();
    __NOP();
    __NOP();
    __NOP();
    __NOP();
    __NOP();
    __NOP();
}

void INTKWUP_IRQHandler(void);
int main(void)
{
    KWUP_SettingTypeDef keySetting;
    KWUP_PortStatus portStatus;
	TSB_KWUP_TypeDef * TSB_KWUPx;

	CG_SetSTBYMode(CG_STBY_MODE_STOP1);
    /* set PAD0,PAD1 to Key0,1 */

    TSB_PAD_FR1_PAD0F1 = 1U;
    TSB_PAD_PUP_PAD0UP = 1U;
    TSB_PAD_IE_PAD0IE = 1U;

    TSB_PAD_FR1_PAD1F1 = 1U;
    TSB_PAD_PUP_PAD1UP = 1U;
    TSB_PAD_IE_PAD1IE = 1U;

    LED_Init();
    LED_On(LED0);

    keySetting.KeyN = KWUP_INPUT_0;
    keySetting.PullUpCtrl = KWUP_PUP_CTRL_BY_STATIC;
    keySetting.ActiveState = KWUP_ACTIVE_BY_RISING_EDGE;
    keySetting.INTNewState = ENABLE;
	TSB_KWUPx=TSB_KWUPA;

	KWUP_SetConfig(TSB_KWUPx,&keySetting);
	
    KWUP_SetPullUpConfig(TSB_KWUPx,KWUP_CYCLES_4_FS, KWUP_CYCLES_256_FS);

 
    /* enable low power mode release interrupt to INTKWUP0 */
    TSB_CG->IMCGF = 0x00100000U;
    TSB_CG->IMCGF += 0x00010000U;
	
	/* enable KWUP interrupt */
    NVIC_ClearPendingIRQ(INTKWUPA_IRQn);
    NVIC_EnableIRQ(INTKWUPA_IRQn);

    do {
        portStatus = KWUP_GetPortStatus(TSB_KWUPx);

        if (portStatus.Bit.Key1 == 0U) {        /* press key(PAD1) */

            LED_On(LED1);
            /* enter low power mode */
            __WFI_wait();
            /* press KEY(PAD0) to release low power mode */

            LED_On(LED2);
        }
    }
    while (1);

}

#ifdef DEBUG
void assert_failed(char *file, int32_t line)
{
    while (1) {
        __NOP();
    }
}
#endif


void INTKWUPA_IRQHandler(void)
{
   
 	KWUP_GetINTStatus(TSB_KWUPA);
    TSB_CG->ICRCG = CG_INT_SRC_KWUP;
}
