/**
 *******************************************************************************
 * @file    rtc.c
 * @brief   the application functions of RTC demo for the TOSHIBA
 *          'TMPM440' Device Series
 * @version V0.101
 * @date    2014/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "rtc.h"
#include <stdio.h>
/**
  * @brief  Initialize RTC register and variables
  * @param  None
  * @retval None
  */

void RTC_Init(void)
{
    RTC_DateTypeDef Date_Struct;
    RTC_TimeTypeDef Time_Struct;

    Date_Struct.LeapYear = RTC_LEAP_YEAR_2;
    Date_Struct.Year = (uint8_t) 10U;
    Date_Struct.Month = (uint8_t) 10U;
    Date_Struct.Date = (uint8_t) 22U;
    Date_Struct.Day = RTC_FRI;

    Time_Struct.HourMode = RTC_24_HOUR_MODE;
    Time_Struct.Hour = (uint8_t) 23U;
    Time_Struct.Min = (uint8_t) 59U;
    Time_Struct.Sec = (uint8_t) 0U;

    RTC_DisableClock();

    /* Reset RTC sec counter */
    RTC_ResetClockSec();
    RTC_EnableClock();

    /* Set RTC Time value */
    RTC_SetTimeValue(&Time_Struct);
    /* Set RTC Date value */
    RTC_SetDateValue(&Date_Struct);

    /* Disable RTCINT */
    RTC_SetRTCINT(DISABLE);

}

/**
  * @brief  Send RTC Date value Time value to LCD.
  * @param  None
  * @retval None
  */
void RTC_Display(void)
{
    uint8_t Sec;
    LED_Off(LED_ALL);
    Sec = RTC_GetSec();
    /* Display */
    TSB_LED->DATA = Sec;
}
