/** 
 *******************************************************************************
 * @file    main.c
 * @brief   the application functions of TMRB_PPG demo for the TOSHIBA
 *          'TMPM440' Device Series 
 * @version V0.101
 * @date    2014/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "main.h"

/**
  * @brief  delay some time
  * @param  delay time
  * @retval None.
  */
void delay(uint32_t time)
{
    volatile uint32_t i;
    for (i = 0U; i < time; i++) {
        /* Do nothing */
    }
}

/**
  * @brief  The main function of TMRB_PPG demo
  * @param  None
  * @retval None
  */
int main(void)
{
    uint8_t Rate = 0U;
    uint32_t LeadingTiming[5] = { 0x15F9U, 0x124FU, 0xC35U, 0x61AU, 0x271U };      /* LeadingTiming: 10%, 25%, 50%, 75%, 90% */
    uint8_t keyvalue;
    uint8_t changestatus = 0U;

    TMRB_InitTypeDef m_tmrb;
    TMRB_FFOutputTypeDef PPGFFInital;

    SW_Init();                  /* init sw port to input */
    
    /* Set PW4 as TB12OUT for PPG output */
    TSB_PW->CR |= 0x10U;
    TSB_PW->FR1 |= 0x10U;
    TSB_PW->IE &= 0U;
    m_tmrb.Mode = TMRB_INTERVAL_TIMER;
    m_tmrb.ClkDiv = TMRB_CLK_DIV_8;
    m_tmrb.UpCntCtrl = TMRB_AUTO_CLEAR;
    m_tmrb.TrailingTiming = TMRB12TIME;  /* T = 500us */
    m_tmrb.LeadingTiming = LeadingTiming[Rate];
    PPGFFInital.FlipflopCtrl = TMRB_FLIPFLOP_CLEAR;
    PPGFFInital.FlipflopReverseTrg = TMRB_FLIPFLOP_MATCH_TRAILINGTIMING | TMRB_FLIPFLOP_MATCH_LEADINGTIMING;

    TMRB_Enable(TSB_TB12);
    TMRB_Init(TSB_TB12, &m_tmrb);
    TMRB_SetFlipFlop(TSB_TB12, &PPGFFInital);
    TMRB_SetDoubleBuf(TSB_TB12, ENABLE);        /* enable double buffer */
    TMRB_SetRunState(TSB_TB12, TMRB_RUN);

    while (1U) {
        /* change SW1 status to change the leadingtiming */
        keyvalue = SW_Get(SW1);
        if (keyvalue == 0U) {
            delay(0xFFFU);      /* noise cancel */
            keyvalue = SW_Get(SW1);
            if (keyvalue == 1U) {
                changestatus = 1U;
            } else {
                /* Do nothing */
            }
        } else if (keyvalue == 1U) {
            delay(0xFFFU);      /* noise cancel */
            keyvalue = SW_Get(SW1);
            if (keyvalue == 0U) {
                changestatus = 1U;
            } else {
                /* Do nothing */
            }
        }
        if (changestatus == 1U) {
            Rate++;             /* change leadingtiming rate */
            if (Rate >= LEADINGTIMINGMAX) {
                Rate = LEADINGTIMINGINIT;
            } else {
                /* Do nothing */
            }
            TMRB_ChangeLeadingTiming(TSB_TB12, LeadingTiming[Rate]);
            changestatus = 0U;
        } else {
            /* Do nothing */
        }
    }
}

/**
  * @brief  Deal with the error parameter
  * @param  file: Pointer to the file where the error parameter locates
  * @param  line: Number of the line in which the error parameter locates
  * @retval None
  */
#ifdef DEBUG
void assert_failed(char *file, int32_t line)
{
    while (1U) {
        __NOP();
    }
}
#endif
