/** 
 *******************************************************************************
 * @file    main.c
 * @brief   The application functions of TMRD interval timer demo for the TOSHIBA
 *          'TMPM440' Device Series 
 * @version V0.101
 * @date    2014/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */

#include "tmpm440_tmrd.h"
#include "tmpm440_cg.h"
#include "led.h"

/* fosc = 10MHz(external high-speed oscillator)
 * fpll = 10 * fosc = 100MHz(in this demo, PLL multiplying value is set to 10 multiplying)
 * ftmrd = fpll / 2 = 50MHz(in this demo, ftmrd = fpll/2, please see CG_SetFtmrdSrc())
 * So the value of TIME_500US is 500us*ftmrd = 25000 = 0x61A8
 */
#define TIME_500US    ((uint16_t)0x61A8U)

int main(void)
{
    LED_Init();

    /* TMRD CG setting */
    CG_SetFtmrdSrc(CG_TMRD_UNIT_A, CG_FTMRD_SRC_HALF_FC);
    CG_SetTMRDClk(CG_TMRD_UNIT_A, ENABLE);

    /* TMRD mode setting */
    TMRD_SetMode(TSB_TD, TMRD_MODE_BOTH_TMR);

    /* TMRD IDLE mode */
    TMRD_SetRunStateInIdle(TSB_TD, TMRD_UNIT_CH_0, TMRD_RUN);

    /* TMRD enable clock signal */
    TMRD_Enable(TSB_TD, TMRD_UNIT_CH_0);

    /* Set the TMRD prescaler */
    TMRD_SetClkDivision(TSB_TD, TMRD_UNIT_CH_0, TMRD_CLK_DIV_1);

    /* Set the upcounter clear mode */
    TMRD_SetUpCntCtrl(TSB_TD, TMRD_UNIT_CH_0, TMRD_AUTO_CLEAR);

    /* Direct update the compare register */
    TMRD_SetCMPRegWritePath(TSB_TD, TMRD_UNIT_CH_0, TMRD_CMP_WRITE_DIRECT);

    /* Set the value to timer register */
    TMRD_ChangeTiming(TSB_TD, TMRD_TIMING_TD0_CYCLE, TIME_500US);      /* 500us */

    /* Indirct update the compare register */
    TMRD_SetCMPRegWritePath(TSB_TD, TMRD_UNIT_CH_0, TMRD_CMP_WRITE_INDIRECT);

    /* Enable TMRD intterrupt */
    TMRD_SetCMP0INTSrc(TSB_TD, TMRD_UNIT_CH_0, TMRD_INT_MATCH_CYCLE);

    NVIC_EnableIRQ(INTTD0CMP0_IRQn);

    /* Start to run TMRD */
    TMRD_SetRunState(TSB_TD, TMRD_UNIT_CH_0, TMRD_RUN);

    while (1) {
        /* Do nothing */
    }
}

#ifdef DEBUG
void assert_failed(char *file, int32_t line)
{
    while (1) {
        __NOP();
    }
}
#endif
